Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(123)

Unified Diff: content/child/child_thread_impl.cc

Issue 1361963002: Re-land architecture for cross-process memory notification suppressing (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed patch Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/child/child_thread_impl.cc
diff --git a/content/child/child_thread_impl.cc b/content/child/child_thread_impl.cc
index 890b30a7712e4a7bfb95964314b9722d56ba8441..2e89519f36cb9cb4aebfde33380aa809ac0dd0e3 100644
--- a/content/child/child_thread_impl.cc
+++ b/content/child/child_thread_impl.cc
@@ -39,6 +39,7 @@
#include "content/child/fileapi/file_system_dispatcher.h"
#include "content/child/fileapi/webfilesystem_impl.h"
#include "content/child/geofencing/geofencing_message_filter.h"
+#include "content/child/memory/child_memory_message_filter.h"
#include "content/child/mojo/mojo_application.h"
#include "content/child/notifications/notification_dispatcher.h"
#include "content/child/power_monitor_broadcast_source.h"
@@ -439,10 +440,11 @@ void ChildThreadImpl::Init(const Options& options) {
channel_->AddFilter(geofencing_message_filter_->GetFilter());
if (!IsInBrowserProcess()) {
// In single process mode, browser-side tracing will cover the whole
// process including renderers.
channel_->AddFilter(new tracing::ChildTraceMessageFilter(
ChildProcess::current()->io_task_runner()));
+ channel_->AddFilter(new ChildMemoryMessageFilter());
}
// In single process mode we may already have a power monitor
@@ -439,10 +440,11 @@ void ChildThreadImpl::Init(const Options& options) {
channel_->AddFilter(geofencing_message_filter_->GetFilter());
if (!IsInBrowserProcess()) {
- // In single process mode, browser-side tracing will cover the whole
- // process including renderers.
+ // In single process mode, browser-side tracing and memory will cover the
+ // whole process including renderers.
channel_->AddFilter(new tracing::ChildTraceMessageFilter(
ChildProcess::current()->io_task_runner()));

Powered by Google App Engine
This is Rietveld 408576698